natural_abundance

Function natural_abundance 

pub fn natural_abundance(isotope: &Isotope) -> Option<f64>
Natural isotopic abundance for a given isotope, as a fraction (0.0 to 1.0).

Returns None if the isotope is not in the database (e.g., synthetic isotopes). Data from IUPAC 2016 recommended values (via NIST).